@@ -1,74 +1,14 @@
-import codecs
-import urllib
+try:
+    from urllib import urlencode
+except ImportError:
+    from urllib.parse import urlencode
 
 import requests
-
-try:
-    from mimetools import choose_boundary
-except ImportError:
-    from requests.packages.urllib3.packages.mimetools_choose_boundary import choose_boundary
-
-from io import BytesIO
-
-from requests.packages.urllib3.packages import six
-from requests.packages.urllib3.filepost import get_content_type, iter_fields
+import six
 
 import soundcloud
-import hashconversions
 
-writer = codecs.lookup('utf-8')[3]
-
-
-def b(s):
-    return s.encode('utf-8')
-
-
-def encode_multipart_formdata(fields, boundary=None):
-    """Fix bug in multipart/form-data POST request handling.
-
-    For some reason, the specific combination of Rack + Ruby + Rails versions
-    that we are using in production has trouble handling multipart/form-data
-    POST requests where the non-binary parts have a Content-Type header. To
-    get around this, we just monkey patch the ```encode_multipart_formdata```
-    function in ```urllib3``` and modify it to *not* set the Content-Type
-    header on non-binary parts.
-    """
-    body = BytesIO()
-    if boundary is None:
-        boundary = choose_boundary()
-
-    for fieldname, value in iter_fields(fields):
-        body.write(b('--%s\r\n' % (boundary)))
-
-        if isinstance(value, tuple):
-            filename, data = value
-            writer(body).write(b(u'Content-Disposition: form-data; name="{0}"; '
-                               u'filename="{1}"\r\n'.format(fieldname, filename)))
-            body.write(b(u'Content-Type: {0}\r\n\r\n'.format(get_content_type(filename))))
-        else:
-            data = value
-            writer(body).write(
-                b(u'Content-Disposition: form-data; name="{0}"\r\n\r\n'.format(
-                    fieldname)))
-
-        if isinstance(data, int):
-            data = str(int)  # Backwards compatibility
-
-        if isinstance(data, six.text_type):
-            writer(body).write(data)
-        else:
-            body.write(data)
-
-        body.write('\r\n')
-
-    body.write(b(u'--{0}--\r\n'.format(boundary)))
-
-    content_type = b(u'multipart/form-data; boundary={0}'.format(boundary))
-
-    return body.getvalue(), content_type
-
-# monkey patch urllib3 to use our modified function
-requests.models.encode_multipart_formdata = encode_multipart_formdata
+from . import hashconversions
 
 
 def is_file_like(f):
@@ -83,12 +23,12 @@ def extract_files_from_dict(d):
     ... 'oauth_token': 'foo',
     ... 'track': {
     ...   'title': 'bar',
-    ...   'asset_data': file('setup.py', 'rb')
+    ...   'asset_data': open('setup.py', 'rb')
     ...  }})  # doctest:+ELLIPSIS
-    {'track': {'asset_data': <open file 'setup.py', mode 'rb' at 0x...}}
+    {'track': {'asset_data': <...}}
     """
     files = {}
-    for key, value in d.iteritems():
+    for key, value in six.iteritems(d):
         if isinstance(value, dict):
             files[key] = extract_files_from_dict(value)
         elif is_file_like(value):
@@ -103,13 +43,14 @@ def remove_files_from_dict(d):
     ...   'oauth_token': 'foo',
     ...   'track': {
     ...       'title': 'bar',
-    ...       'asset_data': file('setup.py', 'rb')
+    ...       'asset_data': open('setup.py', 'rb')
     ...   }
-    ... })  # doctest:+ELLIPSIS
-    {'track': {'title': 'bar'}, 'oauth_token': 'foo'}
+    ... }) == {'track': {'title': 'bar'}, 'oauth_token': 'foo'}
+    ... # doctest:+ELLIPSIS
+    True
     """
     file_free = {}
-    for key, value in d.iteritems():
+    for key, value in six.iteritems(d):
         if isinstance(value, dict):
             file_free[key] = remove_files_from_dict(value)
         elif not is_file_like(value):
@@ -128,12 +69,15 @@ def namespaced_query_string(d, prefix=""):
 
     >>> namespaced_query_string({
     ...  'oauth_token': 'foo',
-    ...  'track': {'title': 'bar', 'sharing': 'private'}})  # doctest:+ELLIPSIS
-    {'track[sharing]': 'private', 'oauth_token': 'foo', 'track[title]': 'bar'}
+    ...  'track': {'title': 'bar', 'sharing': 'private'}}) == {
+    ...      'track[sharing]': 'private',
+    ...      'oauth_token': 'foo',
+    ...      'track[title]': 'bar'}  # doctest:+ELLIPSIS
+    True
     """
     qs = {}
     prefixed = lambda k: prefix and "%s[%s]" % (prefix, k) or k
-    for key, value in d.iteritems():
+    for key, value in six.iteritems(d):
         if isinstance(value, dict):
             qs.update(namespaced_query_string(value, prefix=key))
         else:
@@ -148,14 +92,12 @@ def make_request(method, url, params):
     # TODO
     # del params[key]
     # without list
-    for key, value in params.iteritems():
+    for key, value in six.iteritems(params):
         if value is None:
             empty.append(key)
     for key in empty:
         del params[key]
 
-    
-
     # allow caller to disable automatic following of redirects
     allow_redirects = params.get('allow_redirects', True)
 
@@ -185,8 +127,13 @@ def make_request(method, url, params):
         raise TypeError('Unknown method: %s' % (method,))
 
     if method == 'get':
-        qs = urllib.urlencode(data)
-        result = request_func('%s?%s' % (url, qs), **kwargs)
+        kwargs['headers']['Accept'] = 'application/json'
+        qs = urlencode(data)
+        if '?' in url:
+            url_qs = '%s&%s' % (url, qs)
+        else:
+            url_qs = '%s?%s' % (url, qs)
+        result = request_func(url_qs, **kwargs)
     else:
         kwargs['data'] = data
         if files:
